@@ -10,7 +10,7 @@ Dancer::Plugin::Database - easy database connections for Dancer applications
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 my $dbh;
 my $last_connection_check;
@@ -49,11 +49,23 @@ sub _get_connection {
         $dsn = $settings->{dsn};
     } else {
         $dsn = "dbi:" . $settings->{driver};
+        my @extra_args;
+
+        # DBD::SQLite wants 'dbname', not 'database', so special-case this
+        # (DBI's documentation recommends that DBD::* modules should understand
+        # 'database', but DBD::SQLite doesn't; let's make things easier for our
+        # users by handling this for them):
+        if ($settings->{driver} eq 'SQLite' 
+            && $settings->{database} && !$settings->{dbname}) {
+            $settings->{database} = delete $settings->{dbname};
+        }
+
         for (qw(database host port)) {
             if (exists $settings->{$_}) {
-                $dsn .= ":$_=". $settings->{$_};
+                push @extra_args, $_ . "=" . $settings->{$_};
             }
         }
+        $dsn .= ':' . join(';', @extra_args) if @extra_args;
     }
 
     my $dbh = DBI->connect($dsn, 
@@ -129,8 +141,10 @@ the database keyword within your L<Dancer> application.
 
 Takes care of ensuring that the database handle is still connected and valid.
 If the handle was last asked for more than C<connection_check_threshold> seconds
-ago, it will perform a simple no-op query against the database and check that it
-worked; if not, a new connection will be obtained.  This avoids any problems for
+ago, it will check that the connection is still alive, using either the 
+C<< $dbh->ping >> method if the DBD driver supports it, or performing a simple
+no-op query against the database if not.  If the connection has gone away, a new
+connection will be obtained and returned.  This avoids any problems for
 a long-running script where the connection to the database might go away.
 
 =head1 CONFIGURATION
@@ -185,6 +199,7 @@ connection has gone away), in which case a fresh connection will be obtained.
 David Precious, C<< <davidp@preshweb.co.uk> >>
 
 
+
 =head1 CONTRIBUTING
 
 This module is developed on Github at:
